
Contact
=======

.. include:: ../../README.rst
    :start-after: ---------
    :end-before: License

.. include:: ../../CONTRIBUTIONS.rst
    :start-after: BSD (3-clause)
    :end-before: **Related publications**
